@@ -4,16 +4,30 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
+use AnyEvent;
 use Carp qw( croak );
 
 my %REGISTERED_EVENTS;
 my %MODULES_IDX;
 
+__PACKAGE__->register( __PACKAGE__,
+  'finalize:r' => sub {
+    my $cb = pop if ref( $_[-1] ) eq 'CODE';
+
+    undef %REGISTERED_EVENTS;
+    undef %MODULES_IDX;
+
+    if ( defined $cb ) {
+      AE::postpone { $cb->() };
+    }
+  }
+);
+
 
 sub register {
-  my $self_class   = shift;
+  my $class        = shift;
   my $module_class = shift;
   my %handlers     = @_;
 
@@ -27,9 +41,7 @@ sub register {
   my $events_idx = $MODULES_IDX{$module_class};
 
   while ( my ( $event_name, $handler ) = each %handlers ) {
-    if ( exists $events_idx->{$event_name} ) {
-      croak qq{"$event_name" handler for "$module_class" already registered};
-    }
+    next if exists $events_idx->{$event_name};
     $events_idx->{$event_name} = 1;
 
     unless ( exists $REGISTERED_EVENTS{$event_name} ) {
@@ -47,7 +59,7 @@ sub register {
 }
 
 sub send_event {
-  my $self_class = shift;
+  my $class      = shift;
   my $event_name = shift;
 
   unless ( defined $event_name ) {
@@ -60,7 +72,7 @@ sub send_event {
 
   if ( ref( $_[-1] ) eq 'CODE' ) {
     my $cb = pop @_;
-    $self_class->_async_call_handler( \@handlers, [@_], $cb );
+    $class->_async_call_handler( \@handlers, [@_], $cb );
   }
   else {
     foreach my $handler (@handlers) {
@@ -72,7 +84,7 @@ sub send_event {
 }
 
 sub _async_call_handler {
-  my $self_class = shift;
+  my $class = shift;
   my $handlers   = shift;
   my $args       = shift;
   my $cb         = shift;
@@ -86,7 +98,7 @@ sub _async_call_handler {
 
   $handler->( @{$args},
     sub {
-      $self_class->_async_call_handler( $handlers, $args, $cb );
+      $class->_async_call_handler( $handlers, $args, $cb );
     }
   );
 
@@ -140,10 +152,10 @@ common resources.
 
 =head2 register( $class, \%handlers )
 
-Registers handlers for specified events. When an event have been sent, event
-handlers will be processed in order in which they was registered. If you want
-that event handlers have been processed in reverse order, add postfix C<:r> to
-event name.
+Perform registration of handlers for specified events. When an event have been
+sent, event handlers will be processed in order in which they was registered.
+If you want that event handlers have been processed in reverse order, add
+postfix C<:r> to event name.
 
 =head2 send_event( $event [, @args ] [, $cb->() ] )
 
