@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 use App::Environ;
 use Config::Processor;
@@ -14,7 +14,7 @@ use Carp qw( croak );
 my @REGISTERED_SECTIONS;
 my $CONFIG;
 my %SECTIONS_IDX;
-my $NEED_INIT = 0;
+my $NEED_LOAD_CONFIG;
 
 
 App::Environ->register( __PACKAGE__,
@@ -32,9 +32,11 @@ sub register {
     next if $SECTIONS_IDX{$config_section};
     $SECTIONS_IDX{$config_section} = 1;
     push( @REGISTERED_SECTIONS, $config_section );
-  }
 
-  $NEED_INIT = 1;
+    unless ($NEED_LOAD_CONFIG) {
+      $NEED_LOAD_CONFIG = 1;
+    }
+  }
 
   return;
 }
@@ -51,9 +53,9 @@ sub _initialize {
   my $class = shift;
   my $cb = pop if ref( $_[-1] ) eq 'CODE';
 
-  if ($NEED_INIT) {
+  if ($NEED_LOAD_CONFIG) {
     $class->_load_config;
-    $NEED_INIT = 0;
+    undef $NEED_LOAD_CONFIG;
   }
 
   if ( defined $cb ) {
@@ -97,9 +99,15 @@ sub _load_config {
   }
 
   my $config_processor = Config::Processor->new(
-    dirs                  => \@config_dirs,
-    interpolate_variables => $ENV{APPCONF_INTERPOLATE_VARIABLES},
-    process_directives    => $ENV{APPCONF_PROCESS_DIRECTIVES},
+    dirs => \@config_dirs,
+
+    $ENV{APPCONF_INTERPOLATE_VARIABLES}
+    ? ( interpolate_variables => $ENV{APPCONF_INTERPOLATE_VARIABLES} )
+    : (),
+
+    $ENV{APPCONF_PROCESS_DIRECTIVES}
+    ? ( process_directives => $ENV{APPCONF_PROCESS_DIRECTIVES} )
+    : (),
   );
 
   $CONFIG = $config_processor->load(@REGISTERED_SECTIONS);
@@ -130,7 +138,7 @@ Allows get access to configuraton tree from different application components.
 
 =head2 register( @config_sections )
 
-Registers configuration sections.
+Perform registration of configuration sections.
 
 =head2 instance()
 
